;;;
;;; Copyright (c) 2003-2013 uim Project https://github.com/uim/uim
;;;
;;; All rights reserved.
;;;
;;; Redistribution and use in source and binary forms, with or without
;;; modification, are permitted provided that the following conditions
;;; are met:
;;; 1. Redistributions of source code must retain the above copyright
;;;    notice, this list of conditions and the following disclaimer.
;;; 2. Redistributions in binary form must reproduce the above copyright
;;;    notice, this list of conditions and the following disclaimer in the
;;;    documentation and/or other materials provided with the distribution.
;;; 3. Neither the name of authors nor the names of its contributors
;;;    may be used to endorse or promote products derived from this software
;;;    without specific prior written permission.
;;;
;;; THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS'' AND
;;; ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
;;; IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
;;; ARE DISCLAIMED.  IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR CONTRIBUTORS BE LIABLE
;;; FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
;;; DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
;;; OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
;;; HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
;;; LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
;;; OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
;;; SUCH DAMAGE.
;;;;

;;
(require "generic.scm")
;;
(define tcode-rule
  '(
    ;((("1" "1"))(""))
    ;((("2" "1"))(""))
    ;((("3" "1"))(""))
    ;((("4" "1"))(""))
    ;((("5" "1"))(""))
    ;((("6" "1"))(""))
    ;((("7" "1"))(""))
    ;((("8" "1"))(""))
    ;((("9" "1"))(""))
    ;((("0" "1"))(""))
    ((("," "1"))(""))
    ((("." "1"))(""))
    ((("p" "1"))(""))
    ((("y" "1"))(""))
    ;((("f" "1"))(""))
    ;((("g" "1"))(""))
    ;((("c" "1"))(""))
    ((("r" "1"))(""))
    ((("l" "1"))(""))
    ((("a" "1"))("" ""))
    ((("o" "1"))("õ"))
    ((("e" "1"))(""))
    ((("u" "1"))(""))
    ((("i" "1"))(""))
    ((("d" "1"))("" ""))
    ((("h" "1"))(""))
    ((("t" "1"))(""))
    ((("n" "1"))(""))
    ((("s" "1"))("" ""))
    (((";" "1"))(""))
    ((("q" "1"))(""))
    ((("j" "1"))(""))
    ((("k" "1"))(""))
    ;((("x" "1"))(""))
    ;((("b" "1"))(""))
    ((("m" "1"))(""))
    ((("w" "1"))(""))
    ;((("v" "1"))(""))
    ;((("z" "1"))(""))
    ((("/" "1"))(""))
    ;((("1" "2"))(""))
    ;((("2" "2"))(""))
    ;((("3" "2"))(""))
    ;((("4" "2"))(""))
    ;((("5" "2"))(""))
    ;((("6" "2"))(""))
    ;((("7" "2"))(""))
    ;((("8" "2"))(""))
    ;((("9" "2"))(""))
    ;((("0" "2"))(""))
    ((("," "2"))(""))
    ((("." "2"))(""))
    ((("p" "2"))(""))
    ((("y" "2"))(""))
    ((("f" "2"))(""))
    ;((("g" "2"))(""))
    ;((("c" "2"))(""))
    ((("r" "2"))(""))
    ((("l" "2"))(""))
    ((("a" "2"))(""))
    ((("o" "2"))(""))
    ((("e" "2"))(""))
    ((("u" "2"))(""))
    ((("i" "2"))(""))
    ((("d" "2"))(""))
    ((("h" "2"))(""))
    ((("t" "2"))(""))
    ((("n" "2"))(""))
    ((("s" "2"))(""))
    (((";" "2"))(""))
    ((("q" "2"))(""))
    ((("j" "2"))(""))
    ((("k" "2"))(""))
    ;((("x" "2"))(""))
    ;((("b" "2"))(""))
    ((("m" "2"))(""))
    ((("w" "2"))(""))
    ;((("v" "2"))(""))
    ;((("z" "2"))(""))
    ((("/" "2"))(""))
    ;((("1" "3"))(""))
    ;((("2" "3"))(""))
    ;((("3" "3"))(""))
    ;((("4" "3"))(""))
    ;((("5" "3"))(""))
    ;((("6" "3"))(""))
    ;((("7" "3"))(""))
    ;((("8" "3"))(""))
    ;((("9" "3"))(""))
    ;((("0" "3"))(""))
    ((("," "3"))(""))
    ((("." "3"))(""))
    ((("p" "3"))(""))
    ((("y" "3"))(""))
    ((("f" "3"))(""))
    ((("g" "3"))(""))
    ;((("c" "3"))(""))
    ((("r" "3"))(""))
    ((("l" "3"))(""))
    ((("a" "3"))(""))
    ((("o" "3"))(""))
    ((("e" "3"))(""))
    ((("u" "3"))(""))
    ((("i" "3"))(""))
    ((("d" "3"))(""))
    ((("h" "3"))(""))
    ((("t" "3"))(""))
    ((("n" "3"))(""))
    ((("s" "3"))(""))
    (((";" "3"))("" ""))
    ((("q" "3"))(""))
    ((("j" "3"))(""))
    ((("k" "3"))(""))
    ;((("x" "3"))(""))
    ;((("b" "3"))(""))
    ((("m" "3"))(""))
    ((("w" "3"))(""))
    ;((("v" "3"))(""))
    ;((("z" "3"))(""))
    ((("/" "3"))(""))
    ;((("1" "4"))(""))
    ;((("2" "4"))(""))
    ;((("3" "4"))(""))
    ;((("4" "4"))(""))
    ;((("5" "4"))(""))
    ;((("6" "4"))(""))
    ;((("7" "4"))(""))
    ;((("8" "4"))(""))
    ;((("9" "4"))(""))
    ;((("0" "4"))(""))
    ((("," "4"))("ɧ"))
    ((("." "4"))(""))
    ((("p" "4"))(""))
    ((("y" "4"))(""))
    ((("f" "4"))(""))
    ((("g" "4"))(""))
    ;((("c" "4"))(""))
    ((("r" "4"))(""))
    ((("l" "4"))(""))
    ((("a" "4"))(""))
    ((("o" "4"))(""))
    ((("e" "4"))(""))
    ((("u" "4"))(""))
    ((("i" "4"))(""))
    ((("d" "4"))(""))
    ((("h" "4"))("ˮ"))
    ((("t" "4"))(""))
    ((("n" "4"))(""))
    ((("s" "4"))(""))
    (((";" "4"))(""))
    ((("q" "4"))(""))
    ((("j" "4"))(""))
    ((("k" "4"))(""))
    ;((("x" "4"))(""))
    ;((("b" "4"))(""))
    ((("m" "4"))(""))
    ((("w" "4"))(""))
    ;((("v" "4"))(""))
    ;((("z" "4"))(""))
    ((("/" "4"))("")) 
    ;((("1" "5"))(""))
    ;((("2" "5"))(""))
    ;((("3" "5"))(""))
    ;((("4" "5"))(""))
    ;((("5" "5"))(""))
    ;((("6" "5"))(""))
    ;((("7" "5"))(""))
    ;((("8" "5"))(""))
    ;((("9" "5"))(""))
    ;((("0" "5"))(""))
    ((("," "5"))(""))
    ((("." "5"))(""))
    ((("p" "5"))(""))
    ((("y" "5"))(""))
    ;((("f" "5"))(""))
    ;((("g" "5"))(""))
    ;((("c" "5"))(""))
    ((("r" "5"))(""))
    ((("l" "5"))(""))
    ;((("a" "5"))(""))
    ((("o" "5"))(""))
    ((("e" "5"))(""))
    ((("u" "5"))(""))
    ((("i" "5"))("̩"))
    ;((("d" "5"))(""))
    ((("h" "5"))(""))
    ;((("t" "5"))(""))
    ((("n" "5"))("¬"))
    ;((("s" "5"))(""))
    (((";" "5"))(""))
    ((("q" "5"))(""))
    ((("j" "5"))(""))
    ((("k" "5"))(""))
    ;((("x" "5"))(""))
    ;((("b" "5"))(""))
    ((("m" "5"))(""))
    ((("w" "5"))("˿"))
    ;((("v" "5"))(""))
    ;((("z" "5"))(""))
    ((("/" "5"))(""))
    ;((("1" "6"))(""))
    ;((("2" "6"))(""))
    ;((("3" "6"))(""))
    ;((("4" "6"))(""))
    ;((("5" "6"))(""))
    ;((("6" "6"))(""))
    ;((("7" "6"))(""))
    ;((("8" "6"))(""))
    ;((("9" "6"))(""))
    ;((("0" "6"))(""))
    ;((("," "6"))(""))
    ;((("." "6"))(""))
    ;((("p" "6"))(""))
    ;((("y" "6"))(""))
    ((("f" "6"))(""))
    ((("g" "6"))(""))
    ((("c" "6"))(""))
    ((("r" "6"))(""))
    ;((("l" "6"))(""))
    ((("a" "6"))(""))
    ;((("o" "6"))(""))
    ((("e" "6"))(""))
    ;((("u" "6"))(""))
    ;((("i" "6"))(""))
    ((("d" "6"))(""))
    ;((("h" "6"))(""))
    ((("t" "6"))(""))
    ;((("n" "6"))(""))
    ((("s" "6"))(""))
    ;(((";" "6"))(""))
    ((("q" "6"))(""))
    ;((("j" "6"))(""))
    ;((("k" "6"))(""))
    ((("x" "6"))(""))
    ((("b" "6"))(""))
    ;((("m" "6"))(""))
    ((("w" "6"))(""))
    ((("v" "6"))(""))
    ((("z" "6"))(""))
    ;((("/" "6"))(""))
    ;((("1" "7"))(""))
    ;((("2" "7"))(""))
    ;((("3" "7"))(""))
    ;((("4" "7"))(""))
    ;((("5" "7"))(""))
    ;((("6" "7"))(""))
    ;((("7" "7"))(""))
    ;((("8" "7"))(""))
    ;((("9" "7"))(""))
    ;((("0" "7"))(""))
    ;((("," "7"))(""))
    ;((("." "7"))(""))
    ((("p" "7"))(""))
    ;((("y" "7"))(""))
    ((("f" "7"))(""))
    ((("g" "7"))("æ"))
    ((("c" "7"))(""))
    ((("r" "7"))(""))
    ((("l" "7"))("º"))
    ((("a" "7"))(""))
    ((("o" "7"))(""))
    ((("e" "7"))("͹"))
    ((("u" "7"))(""))
    ((("i" "7"))(""))
    ((("d" "7"))(""))
    ((("h" "7"))(""))
    ((("t" "7"))(""))
    ;((("n" "7"))(""))
    ((("s" "7"))(""))
    ;(((";" "7"))(""))
    ((("q" "7"))("ü"))
    ((("j" "7"))(""))
    ((("k" "7"))(""))
    ((("x" "7"))(""))
    ((("b" "7"))(""))
    ;((("m" "7"))(""))
    ((("w" "7"))(""))
    ((("v" "7"))(""))
    ((("z" "7"))(""))
    ;((("/" "7"))(""))
    ;((("1" "8"))(""))
    ;((("2" "8"))(""))
    ;((("3" "8"))(""))
    ;((("4" "8"))(""))
    ;((("5" "8"))(""))
    ;((("6" "8"))(""))
    ;((("7" "8"))(""))
    ;((("8" "8"))(""))
    ;((("9" "8"))(""))
    ;((("0" "8"))(""))
    ;((("," "8"))(""))
    ;((("." "8"))(""))
    ((("p" "8"))(""))
    ((("y" "8"))(""))
    ((("f" "8"))(""))
    ((("g" "8"))("˽"))
    ((("c" "8"))(""))
    ((("r" "8"))(""))
    ;((("l" "8"))(""))
    ((("a" "8"))(""))
    ((("o" "8"))(""))
    ((("e" "8"))(""))
    ((("u" "8"))(""))
    ((("i" "8"))(""))
    ((("d" "8"))(""))
    ;((("h" "8"))(""))
    ((("t" "8"))(""))
    ;((("n" "8"))(""))
    ((("s" "8"))(""))
    ;(((";" "8"))(""))
    ((("q" "8"))(""))
    ;((("j" "8"))(""))
    ;((("k" "8"))(""))
    ((("x" "8"))(""))
    ((("b" "8"))("ʻ"))
    ;((("m" "8"))(""))
    ((("w" "8"))(""))
    ((("v" "8"))("ε"))
    ((("z" "8"))(""))
    ;((("/" "8"))(""))
    ;((("1" "9"))(""))
    ;((("2" "9"))(""))
    ;((("3" "9"))(""))
    ;((("4" "9"))(""))
    ;((("5" "9"))(""))
    ;((("6" "9"))(""))
    ;((("7" "9"))(""))
    ;((("8" "9"))(""))
    ;((("9" "9"))(""))
    ;((("0" "9"))(""))
    ;((("," "9"))(""))
    ;((("." "9"))(""))
    ((("p" "9"))("Ģ"))
    ;((("y" "9"))(""))
    ((("f" "9"))(""))
    ((("g" "9"))(""))
    ((("c" "9"))(""))
    ((("r" "9"))(""))
    ;((("l" "9"))(""))
    ((("a" "9"))(""))
    ((("o" "9"))(""))
    ((("e" "9"))(""))
    ((("u" "9"))("ǵ"))
    ((("i" "9"))("ǡ"))
    ((("d" "9"))(""))
    ;((("h" "9"))(""))
    ((("t" "9"))(""))
    ;((("n" "9"))(""))
    ((("s" "9"))(""))
    ;(((";" "9"))(""))
    ((("q" "9"))(""))
    ;((("j" "9"))(""))
    ;((("k" "9"))(""))
    ((("x" "9"))(""))
    ((("b" "9"))(""))
    ;((("m" "9"))(""))
    ((("w" "9"))(""))
    ((("v" "9"))("ð"))
    ((("z" "9"))(""))
    ;((("/" "9"))(""))
    ;((("1" "0"))(""))
    ;((("2" "0"))(""))
    ;((("3" "0"))(""))
    ;((("4" "0"))(""))
    ;((("5" "0"))(""))
    ;((("6" "0"))(""))
    ;((("7" "0"))(""))
    ;((("8" "0"))(""))
    ;((("9" "0"))(""))
    ;((("0" "0"))(""))
    ;((("," "0"))(""))
    ;((("." "0"))(""))
    ((("p" "0"))(""))
    ((("y" "0"))(""))
    ((("f" "0"))(""))
    ((("g" "0"))(""))
    ((("c" "0"))(""))
    ((("r" "0"))(""))
    ;((("l" "0"))(""))
    ((("a" "0"))("§"))
    ((("o" "0"))("θ"))
    ((("e" "0"))("ɼ"))
    ((("u" "0"))("ζ"))
    ((("i" "0"))("ά"))
    ((("d" "0"))(""))
    ;((("h" "0"))(""))
    ((("t" "0"))(""))
    ;((("n" "0"))(""))
    ((("s" "0"))("¸"))
    ;(((";" "0"))(""))
    ((("q" "0"))(""))
    ;((("j" "0"))(""))
    ;((("k" "0"))(""))
    ((("x" "0"))(""))
    ((("b" "0"))(""))
    ;((("m" "0"))(""))
    ((("w" "0"))(""))
    ((("v" "0"))(""))
    ((("z" "0"))(""))
    ;((("/" "0"))(""))
    ((("1" ","))("α"))
    ((("2" ","))(""))
    ((("3" ","))(""))
    ((("4" ","))("Ʀ"))
    ((("5" ","))(""))
    ;((("6" ","))(""))
    ;((("7" ","))(""))
    ;((("8" ","))(""))
    ;((("9" ","))(""))
    ;((("0" ","))(""))
    ((("," ","))(""))
    ((("." ","))(""))
    ((("p" ","))(""))
    ((("y" ","))(""))
    ((("f" ","))(""))
    ((("g" ","))(""))
    ((("c" ","))(""))
    ((("r" ","))(""))
    ((("l" ","))(""))
    ((("a" ","))(""))
    ((("o" ","))(""))
    ((("e" ","))(""))
    ((("u" ","))(""))
    ((("i" ","))(""))
    ((("d" ","))(""))
    ((("h" ","))("Ĵ"))
    ((("t" ","))(""))
    ((("n" ","))(""))
    ((("s" ","))(""))
    (((";" ","))(""))
    ((("q" ","))(""))
    ((("j" ","))(""))
    ((("k" ","))(""))
    ((("x" ","))("ʧ"))
    ((("b" ","))(""))
    ((("m" ","))(""))
    ((("w" ","))(""))
    ((("v" ","))(""))
    ((("z" ","))(""))
    ((("/" ","))(""))
    ((("1" "."))(""))
    ((("2" "."))(""))
    ((("3" "."))("?"))
    ((("4" "."))(""))
    ((("5" "."))(""))
    ;((("6" "."))(""))
    ;((("7" "."))(""))
    ;((("8" "."))(""))
    ;((("9" "."))(""))
    ;((("0" "."))(""))
    ((("," "."))("" ""))
    ((("." "."))(""))
    ((("p" "."))(""))
    ((("y" "."))(""))
    ((("f" "."))(""))
    ((("g" "."))("ï"))
    ((("c" "."))(""))
    ((("r" "."))(""))
    ((("l" "."))(""))
    ((("a" "."))("" ""))
    ((("o" "."))(""))
    ((("e" "."))(""))
    ((("u" "."))(""))
    ((("i" "."))(""))
    ((("d" "."))(""))
    ((("h" "."))(""))
    ((("t" "."))(""))
    ((("n" "."))(""))
    ((("s" "."))("Ÿ"))
    (((";" "."))(""))
    ((("q" "."))("" ""))
    ((("j" "."))(""))
    ((("k" "."))(""))
    ((("x" "."))(""))
    ((("b" "."))("ͷ"))
    ((("m" "."))("" ""))
    ((("w" "."))(""))
    ((("v" "."))(""))
    ((("z" "."))(""))
    ((("/" "."))("Ϳ"))
    ((("1" "p"))(""))
    ((("2" "p"))(""))
    ((("3" "p"))(""))
    ((("4" "p"))(""))
    ((("5" "p"))(""))
    ;((("6" "p"))(""))
    ;((("7" "p"))(""))
    ((("8" "p"))(""))
    ((("9" "p"))(""))
    ;((("0" "p"))(""))
    ((("," "p"))(""))
    ((("." "p"))(""))
    ((("p" "p"))(""))
    ((("y" "p"))("̵"))
    ((("f" "p"))(""))
    ((("g" "p"))(""))
    ((("c" "p"))(""))
    ((("r" "p"))(""))
    ((("l" "p"))(""))
    ((("a" "p"))(""))
    ((("o" "p"))(""))
    ((("e" "p"))(""))
    ((("u" "p"))(""))
    ((("i" "p"))(""))
    ((("d" "p"))(""))
    ((("h" "p"))("ͥ"))
    ((("t" "p"))(""))
    ((("n" "p"))(""))
    ((("s" "p"))(""))
    (((";" "p"))(""))
    ((("q" "p"))(""))
    ((("j" "p"))(""))
    ((("k" "p"))(""))
    ((("x" "p"))(""))
    ((("b" "p"))(""))
    ((("m" "p"))("¨"))
    ((("w" "p"))(""))
    ((("v" "p"))(""))
    ((("z" "p"))(""))
    ((("/" "p"))(""))
    ((("1" "y"))(""))
    ((("2" "y"))("ħ"))
    ((("3" "y"))(""))
    ((("4" "y"))(""))
    ((("5" "y"))(""))
    ;((("6" "y"))(""))
    ((("7" "y"))(""))
    ((("8" "y"))(""))
    ((("9" "y"))(""))
    ((("0" "y"))(""))
    ((("," "y"))(""))
    ((("." "y"))(""))
    ((("p" "y"))(""))
    ((("y" "y"))(""))
    ((("f" "y"))(""))
    ((("g" "y"))("˭"))
    ((("c" "y"))(""))
    ((("r" "y"))(""))
    ((("l" "y"))(""))
    ((("a" "y"))(""))
    ((("o" "y"))("Ϻ"))
    ((("e" "y"))(""))
    ((("u" "y"))("ˡ"))
    ((("i" "y"))(""))
    ((("d" "y"))("Ǥ"))
    ((("h" "y"))(""))
    ((("t" "y"))("ɾ"))
    ((("n" "y"))(""))
    ((("s" "y"))(""))
    (((";" "y"))(""))
    ((("q" "y"))(""))
    ((("j" "y"))(""))
    ((("k" "y"))(""))
    ((("x" "y"))(""))
    ((("b" "y"))(""))
    ((("m" "y"))("û"))
    ((("w" "y"))(""))
    ((("v" "y"))("Ψ"))
    ((("z" "y"))(""))
    ((("/" "y"))(""))
    ((("1" "f"))("" ""))
    ((("2" "f"))(""))
    ((("3" "f"))(""))
    ((("4" "f"))(""))
    ((("5" "f"))("ʰ"))
    ((("6" "f"))(""))
    ((("7" "f"))(""))
    ((("8" "f"))(""))
    ((("9" "f"))(""))
    ((("0" "f"))("ɸ"))
    ((("," "f"))("" ""))
    ((("." "f"))(""))
    ((("p" "f"))(""))
    ((("y" "f"))("" ""))
    ((("f" "f"))(""))
    ((("g" "f"))(""))
    ((("c" "f"))(""))
    ((("r" "f"))(""))
    ((("l" "f"))(""))
    ((("a" "f"))(""))
    ((("o" "f"))(""))
    ((("e" "f"))(""))
    ((("u" "f"))("" ""))
    ((("i" "f"))("6"))
    ((("d" "f"))(""))
    ((("h" "f"))(""))
    ((("t" "f"))(""))
    ((("n" "f"))("" ""))
    ((("s" "f"))("ͽ"))
    (((";" "f"))("2"))
    ((("q" "f"))("" ""))
    ((("j" "f"))(""))
    ((("k" "f"))("0"))
    ((("x" "f"))(""))
    ((("b" "f"))(""))
    ((("m" "f"))(""))
    ((("w" "f"))(""))
    ((("v" "f"))(""))
    ((("z" "f"))(""))
    ((("/" "f"))(""))
    ((("1" "g"))("" ""))
    ((("2" "g"))(""))
    ((("3" "g"))(""))
    ((("4" "g"))(""))
    ((("5" "g"))(""))
    ((("6" "g"))(""))
    ((("7" "g"))(";"))
    ((("8" "g"))(""))
    ((("9" "g"))(""))
    ((("0" "g"))(""))
    ((("," "g"))(""))
    ((("." "g"))("Ĺ"))
    ((("p" "g"))(""))
    ((("y" "g"))(""))
    ((("f" "g"))(""))
    ((("g" "g"))(""))
    ((("c" "g"))(""))
    ((("r" "g"))(""))
    ((("l" "g"))("" ""))
    ((("a" "g"))(""))
    ((("o" "g"))(""))
    ((("e" "g"))(""))
    ((("u" "g"))("" ""))
    ((("i" "g"))("" ""))
    ((("d" "g"))(""))
    ((("h" "g"))("" ""))
    ((("t" "g"))("ʹ"))
    ((("n" "g"))(""))
    ((("s" "g"))(""))
    (((";" "g"))("" ""))
    ((("q" "g"))(""))
    ((("j" "g"))("" ""))
    ((("k" "g"))("" ""))
    ((("x" "g"))(""))
    ((("b" "g"))(""))
    ((("m" "g"))(""))
    ((("w" "g"))(""))
    ((("v" "g"))(""))
    ((("z" "g"))("ž"))
    ((("/" "g"))("" ""))
    ((("1" "c"))("" ""))
    ;((("2" "c"))(""))
    ;((("3" "c"))(""))
    ;((("4" "c"))(""))
    ;((("5" "c"))(""))
    ((("6" "c"))("˼"))
    ((("7" "c"))(""))
    ((("8" "c"))(""))
    ((("9" "c"))("°"))
    ((("0" "c"))(""))
    ((("," "c"))(""))
    ((("." "c"))(""))
    ((("p" "c"))("ư"))
    ((("y" "c"))(""))
    ((("f" "c"))(""))
    ((("g" "c"))(""))
    ((("c" "c"))("" ""))
    ((("r" "c"))(""))
    ((("l" "c"))("" ""))
    ((("a" "c"))(""))
    ((("o" "c"))(""))
    ((("e" "c"))("λ"))
    ((("u" "c"))(""))
    ((("i" "c"))("ϻ"))
    ((("d" "c"))(""))
    ((("h" "c"))("" ""))
    ((("t" "c"))("Ǯ"))
    ((("n" "c"))(""))
    ((("s" "c"))("Ƭ"))
    (((";" "c"))(""))
    ((("q" "c"))(""))
    ((("j" "c"))("" ""))
    ((("k" "c"))(""))
    ((("x" "c"))(""))
    ((("b" "c"))(""))
    ((("m" "c"))(""))
    ((("w" "c"))(""))
    ((("v" "c"))(""))
    ((("z" "c"))(""))
    ((("/" "c"))(""))
    ((("1" "r"))(""))
    ((("2" "r"))(""))
    ((("3" "r"))(""))
    ((("4" "r"))(""))
    ((("5" "r"))(""))
    ((("6" "r"))(""))
    ((("7" "r"))(""))
    ((("8" "r"))(""))
    ((("9" "r"))("®"))
    ((("0" "r"))(""))
    ((("," "r"))(""))
    ((("." "r"))(""))
    ((("p" "r"))("Ω"))
    ((("y" "r"))(""))
    ((("f" "r"))("¦"))
    ((("g" "r"))(""))
    ((("c" "r"))(""))
    ((("r" "r"))(""))
    ((("l" "r"))(""))
    ((("a" "r"))(""))
    ((("o" "r"))("ȯ"))
    ((("e" "r"))("ǽ"))
    ((("u" "r"))(""))
    ((("i" "r"))(""))
    ((("d" "r"))(""))
    ((("h" "r"))("" ""))
    ((("t" "r"))(""))
    ((("n" "r"))(""))
    ((("s" "r"))(""))
    (((";" "r"))(""))
    ((("q" "r"))(""))
    ((("j" "r"))("" ""))
    ((("k" "r"))(""))
    ((("x" "r"))(""))
    ((("b" "r"))(""))
    ((("m" "r"))("̾"))
    ((("w" "r"))(""))
    ((("v" "r"))(""))
    ((("z" "r"))("Ŭ"))
    ((("/" "r"))(""))
    ((("1" "l"))(""))
    ((("2" "l"))(""))
    ((("3" "l"))("̴"))
    ((("4" "l"))(""))
    ((("5" "l"))(""))
    ;((("6" "l"))(""))
    ((("7" "l"))(""))
    ;((("8" "l"))(""))
    ((("9" "l"))(""))
    ((("0" "l"))(""))
    ((("," "l"))(""))
    ((("." "l"))(""))
    ((("p" "l"))(""))
    ((("y" "l"))("" ""))
    ((("f" "l"))(""))
    ((("g" "l"))(""))
    ((("c" "l"))(""))
    ((("r" "l"))(""))
    ((("l" "l"))(""))
    ((("a" "l"))("­"))
    ((("o" "l"))(""))
    ((("e" "l"))(""))
    ((("u" "l"))("̱"))
    ((("i" "l"))(""))
    ((("d" "l"))(""))
    ((("h" "l"))(""))
    ((("t" "l"))(""))
    ((("n" "l"))(""))
    ((("s" "l"))(""))
    (((";" "l"))("ʸ"))
    ((("q" "l"))(""))
    ((("j" "l"))(""))
    ((("k" "l"))("ŷ"))
    ((("x" "l"))(""))
    ((("b" "l"))(""))
    ((("m" "l"))(""))
    ((("w" "l"))(""))
    ((("v" "l"))(""))
    ((("z" "l"))(""))
    ((("/" "l"))(""))
    ((("1" "a"))("" ""))
    ((("2" "a"))(""))
    ((("3" "a"))(""))
    ((("4" "a"))(""))
    ((("5" "a"))("ɩ"))
    ((("6" "a"))(""))
    ((("7" "a"))(""))
    ((("8" "a"))("Ļ"))
    ((("9" "a"))(""))
    ((("0" "a"))(""))
    ((("," "a"))(""))
    ((("." "a"))(""))
    ((("p" "a"))(""))
    ((("y" "a"))(""))
    ((("f" "a"))(""))
    ((("g" "a"))(""))
    ((("c" "a"))(""))
    ((("r" "a"))(""))
    ((("l" "a"))("" ""))
    ((("a" "a"))(""))
    ((("o" "a"))("" ""))
    ((("e" "a"))(""))
    ((("u" "a"))(""))
    ((("i" "a"))("" ""))
    ((("d" "a"))(""))
    ((("h" "a"))("3"))
    ((("t" "a"))(""))
    ((("n" "a"))(""))
    ((("s" "a"))(""))
    (((";" "a"))("" ""))
    ((("q" "a"))(""))
    ((("j" "a"))("" ""))
    ((("k" "a"))(""))
    ((("x" "a"))(""))
    ((("b" "a"))(""))
    ((("m" "a"))(""))
    ((("w" "a"))(""))
    ((("v" "a"))(""))
    ((("z" "a"))(""))
    ((("/" "a"))("" ""))
    ((("1" "o"))(""))
    ((("2" "o"))("Ǽ"))
    ((("3" "o"))(""))
    ((("4" "o"))("ƨ"))
    ((("5" "o"))(""))
    ;((("6" "o"))(""))
    ((("7" "o"))(""))
    ((("8" "o"))(""))
    ((("9" "o"))(""))
    ((("0" "o"))(""))
    ((("," "o"))(""))
    ((("." "o"))(""))
    ((("p" "o"))(""))
    ((("y" "o"))(""))
    ((("f" "o"))("" ""))
    ((("g" "o"))(""))
    ((("c" "o"))(""))
    ((("r" "o"))(""))
    ((("l" "o"))(""))
    ((("a" "o"))(""))
    ((("o" "o"))(""))
    ((("e" "o"))(""))
    ((("u" "o"))(""))
    ((("i" "o"))(""))
    ((("d" "o"))(""))
    ((("h" "o"))(""))
    ((("t" "o"))(""))
    ((("n" "o"))(""))
    ((("s" "o"))(""))
    (((";" "o"))(""))
    ((("q" "o"))(""))
    ((("j" "o"))("" ""))
    ((("k" "o"))(""))
    ((("x" "o"))(""))
    ((("b" "o"))(""))
    ((("m" "o"))(""))
    ((("w" "o"))(""))
    ((("v" "o"))(""))
    ((("z" "o"))(""))
    ((("/" "o"))(""))
    ((("1" "e"))(""))
    ((("2" "e"))(""))
    ((("3" "e"))(""))
    ((("4" "e"))(""))
    ((("5" "e"))(""))
    ((("6" "e"))(""))
    ((("7" "e"))(""))
    ((("8" "e"))("Ʈ"))
    ((("9" "e"))(""))
    ((("0" "e"))("ͼ"))
    ((("," "e"))("Ȭ"))
    ((("." "e"))(""))
    ((("p" "e"))(""))
    ((("y" "e"))("" ""))
    ((("f" "e"))(""))
    ((("g" "e"))(""))
    ((("c" "e"))(""))
    ((("r" "e"))(""))
    ((("l" "e"))(""))
    ((("a" "e"))(""))
    ((("o" "e"))(""))
    ((("e" "e"))("ξ"))
    ((("u" "e"))(""))
    ((("i" "e"))(""))
    ((("d" "e"))(""))
    ((("h" "e"))("7"))
    ((("t" "e"))("!"))
    ((("n" "e"))(""))
    ((("s" "e"))(""))
    (((";" "e"))("" ""))
    ((("q" "e"))(""))
    ((("j" "e"))("" ""))
    ((("k" "e"))("("))
    ((("x" "e"))(""))
    ((("b" "e"))(""))
    ((("m" "e"))(""))
    ((("w" "e"))(""))
    ((("v" "e"))(""))
    ((("z" "e"))(""))
    ((("/" "e"))(""))
    ((("1" "u"))(""))
    ((("2" "u"))(""))
    ((("3" "u"))(""))
    ((("4" "u"))(""))
    ((("5" "u"))("ʣ"))
    ;((("6" "u"))(""))
    ((("7" "u"))(""))
    ((("8" "u"))(""))
    ((("9" "u"))(""))
    ((("0" "u"))(""))
    ((("," "u"))(""))
    ((("." "u"))("" ""))
    ((("p" "u"))(""))
    ((("y" "u"))(""))
    ((("f" "u"))(""))
    ((("g" "u"))(""))
    ((("c" "u"))("ι"))
    ((("r" "u"))(""))
    ((("l" "u"))(""))
    ((("a" "u"))(""))
    ((("o" "u"))(""))
    ((("e" "u"))(""))
    ((("u" "u"))(""))
    ((("i" "u"))(""))
    ((("d" "u"))(""))
    ((("h" "u"))(""))
    ((("t" "u"))(""))
    ((("n" "u"))(""))
    ((("s" "u"))(""))
    (((";" "u"))(""))
    ((("q" "u"))(""))
    ((("j" "u"))(""))
    ((("k" "u"))(""))
    ((("x" "u"))(""))
    ((("b" "u"))(""))
    ((("m" "u"))(""))
    ((("w" "u"))(""))
    ((("v" "u"))(""))
    ((("z" "u"))(""))
    ((("/" "u"))(""))
    ((("1" "i"))(""))
    ((("2" "i"))(""))
    ((("3" "i"))(""))
    ((("4" "i"))("ɮ"))
    ((("5" "i"))("Τ"))
    ;((("6" "i"))(""))
    ((("7" "i"))(""))
    ((("8" "i"))(""))
    ((("9" "i"))(""))
    ((("0" "i"))(""))
    ((("," "i"))(""))
    ((("." "i"))("ǰ"))
    ((("p" "i"))(""))
    ((("y" "i"))(""))
    ((("f" "i"))(""))
    ((("g" "i"))(""))
    ((("c" "i"))("ǧ"))
    ((("r" "i"))(""))
    ((("l" "i"))(""))
    ((("a" "i"))(""))
    ((("o" "i"))(""))
    ((("e" "i"))(""))
    ((("u" "i"))("ī"))
    ((("i" "i"))(""))
    ((("d" "i"))("ϫ"))
    ((("h" "i"))(""))
    ((("t" "i"))(""))
    ((("n" "i"))(""))
    ((("s" "i"))(""))
    (((";" "i"))("ë"))
    ((("q" "i"))(""))
    ((("j" "i"))(""))
    ((("k" "i"))(""))
    ((("x" "i"))("Ƴ"))
    ((("b" "i"))(""))
    ((("m" "i"))(""))
    ((("w" "i"))(""))
    ((("v" "i"))(""))
    ((("z" "i"))(""))
    ((("/" "i"))("Ư"))
    ((("1" "d"))("" ""))
    ((("2" "d"))(""))
    ((("3" "d"))(""))
    ((("4" "d"))(""))
    ((("5" "d"))(""))
    ((("6" "d"))(""))
    ((("7" "d"))(""))
    ((("8" "d"))(""))
    ((("9" "d"))("ʩ"))
    ((("0" "d"))(""))
    ((("," "d"))(""))
    ((("." "d"))("" ""))
    ((("p" "d"))(""))
    ((("y" "d"))("" ""))
    ((("f" "d"))("" ""))
    ((("g" "d"))(""))
    ((("c" "d"))(""))
    ((("r" "d"))("³"))
    ((("l" "d"))("5"))
    ((("a" "d"))(""))
    ((("o" "d"))(""))
    ((("e" "d"))(""))
    ((("u" "d"))("4"))
    ((("i" "d"))(")"))
    ((("d" "d"))(""))
    ((("h" "d"))("" ""))
    ((("t" "d"))(""))
    ((("n" "d"))("" ""))
    ((("s" "d"))(""))
    (((";" "d"))("1"))
    ((("q" "d"))(""))
    ((("j" "d"))(""))
    ((("k" "d"))("" ""))
    ((("x" "d"))(""))
    ((("b" "d"))(""))
    ((("m" "d"))("" ""))
    ((("w" "d"))(""))
    ((("v" "d"))("Ⱦ"))
    ((("z" "d"))(""))
    ((("/" "d"))(""))
    ((("1" "h"))(""))
    ((("2" "h"))(""))
    ((("3" "h"))(""))
    ((("4" "h"))(""))
    ((("5" "h"))(""))
    ;((("6" "h"))(""))
    ((("7" "h"))(""))
    ((("8" "h"))(""))
    ((("9" "h"))(""))
    ((("0" "h"))(""))
    ((("," "h"))(""))
    ((("." "h"))("ʿ"))
    ((("p" "h"))("ʪ"))
    ((("y" "h"))("" ""))
    ((("f" "h"))(""))
    ((("g" "h"))(""))
    ((("c" "h"))(""))
    ((("r" "h"))("ϩ"))
    ((("l" "h"))("ƣ"))
    ((("a" "h"))(""))
    ((("o" "h"))(""))
    ((("e" "h"))(""))
    ((("u" "h"))(""))
    ((("i" "h"))(""))
    ((("d" "h"))(""))
    ((("h" "h"))(""))
    ((("t" "h"))(""))
    ((("n" "h"))(""))
    ((("s" "h"))("ɬ"))
    (((";" "h"))("ͭ"))
    ((("q" "h"))(""))
    ((("j" "h"))(""))
    ((("k" "h"))(""))
    ((("x" "h"))("ʼ"))
    ((("b" "h"))(""))
    ((("m" "h"))(""))
    ((("w" "h"))(""))
    ((("v" "h"))(""))
    ((("z" "h"))(""))
    ((("/" "h"))(""))
    ((("1" "t"))(""))
    ((("2" "t"))(""))
    ((("3" "t"))(""))
    ((("4" "t"))(""))
    ((("5" "t"))(""))
    ((("6" "t"))(""))
    ((("7" "t"))(""))
    ((("8" "t"))(""))
    ((("9" "t"))(""))
    ((("0" "t"))(""))
    ((("," "t"))(""))
    ((("." "t"))(""))
    ((("p" "t"))(""))
    ((("y" "t"))(""))
    ((("f" "t"))(""))
    ((("g" "t"))(""))
    ((("c" "t"))(""))
    ((("r" "t"))(""))
    ((("l" "t"))("" ""))
    ((("a" "t"))(""))
    ((("o" "t"))(""))
    ((("e" "t"))(""))
    ((("u" "t"))(""))
    ((("i" "t"))(""))
    ((("d" "t"))("" ""))
    ((("h" "t"))(""))
    ((("t" "t"))("" ""))
    ((("n" "t"))(""))
    ((("s" "t"))(""))
    (((";" "t"))("ǯ"))
    ((("q" "t"))(""))
    ((("j" "t"))("" ""))
    ((("k" "t"))("8"))
    ((("x" "t"))(""))
    ((("b" "t"))(""))
    ((("m" "t"))(""))
    ((("w" "t"))(""))
    ((("v" "t"))(""))
    ((("z" "t"))(""))
    ((("/" "t"))(""))
    ((("1" "n"))(""))
    ((("2" "n"))(""))
    ((("3" "n"))(""))
    ((("4" "n"))(""))
    ((("5" "n"))("ϯ"))
    ;((("6" "n"))(""))
    ;((("7" "n"))(""))
    ;((("8" "n"))(""))
    ;((("9" "n"))(""))
    ;((("0" "n"))(""))
    ((("," "n"))(""))
    ((("." "n"))(""))
    ((("p" "n"))(""))
    ((("y" "n"))(""))
    ((("f" "n"))(""))
    ((("g" "n"))(""))
    ((("c" "n"))(""))
    ((("r" "n"))(""))
    ((("l" "n"))("ɽ"))
    ((("a" "n"))(""))
    ((("o" "n"))(""))
    ((("e" "n"))(""))
    ((("u" "n"))(""))
    ((("i" "n"))(""))
    ((("d" "n"))(""))
    ((("h" "n"))(""))
    ((("t" "n"))(""))
    ((("n" "n"))(""))
    ((("s" "n"))("Ͽ"))
    (((";" "n"))(""))
    ((("q" "n"))(""))
    ((("j" "n"))(""))
    ((("k" "n"))(""))
    ((("x" "n"))(""))
    ((("b" "n"))(""))
    ((("m" "n"))(""))
    ((("w" "n"))("ģ"))
    ((("v" "n"))(""))
    ((("z" "n"))(""))
    ((("/" "n"))(""))
    ((("1" "s"))("" ""))
    ((("2" "s"))(""))
    ((("3" "s"))(""))
    ((("4" "s"))(""))
    ((("5" "s"))("ɳ"))
    ((("6" "s"))("ŵ"))
    ((("7" "s"))(""))
    ((("8" "s"))(""))
    ((("9" "s"))(""))
    ((("0" "s"))(""))
    ((("," "s"))(""))
    ((("." "s"))(""))
    ((("p" "s"))("" ""))
    ((("y" "s"))("" ""))
    ((("f" "s"))(""))
    ((("g" "s"))(""))
    ((("c" "s"))("¢"))
    ((("r" "s"))("" ""))
    ((("l" "s"))(""))
    ((("a" "s"))(""))
    ((("o" "s"))(""))
    ((("e" "s"))(""))
    ((("u" "s"))(""))
    ((("i" "s"))(""))
    ((("d" "s"))(""))
    ((("h" "s"))(""))
    ((("t" "s"))(""))
    ((("n" "s"))(""))
    ((("s" "s"))(""))
    (((";" "s"))("" ""))
    ((("q" "s"))(""))
    ((("j" "s"))("" ""))
    ((("k" "s"))("" ""))
    ((("x" "s"))(""))
    ((("b" "s"))("¤"))
    ((("m" "s"))(""))
    ((("w" "s"))("ͺ"))
    ((("v" "s"))(""))
    ((("z" "s"))(""))
    ((("/" "s"))(""))
    ((("1" ";"))(""))
    ((("2" ";"))(""))
    ((("3" ";"))(""))
    ((("4" ";"))(""))
    ((("5" ";"))(""))
    ;((("6" ";"))(""))
    ((("7" ";"))(""))
    ((("8" ";"))("Ʒ"))
    ((("9" ";"))("ƫ"))
    ;((("0" ";"))(""))
    ((("," ";"))(""))
    ((("." ";"))(""))
    ((("p" ";"))(""))
    ((("y" ";"))(""))
    ((("f" ";"))(""))
    ((("g" ";"))(""))
    ((("c" ";"))(""))
    ((("r" ";"))(""))
    ((("l" ";"))(""))
    ((("a" ";"))(""))
    ((("o" ";"))(""))
    ((("e" ";"))(""))
    ((("u" ";"))(""))
    ((("i" ";"))(""))
    ((("d" ";"))(""))
    ((("h" ";"))(""))
    ((("t" ";"))(""))
    ((("n" ";"))(""))
    ((("s" ";"))(""))
    (((";" ";"))("" ""))
    ((("q" ";"))(""))
    ((("j" ";"))(""))
    ((("k" ";"))(""))
    ((("x" ";"))(""))
    ((("b" ";"))(""))
    ((("m" ";"))(""))
    ((("w" ";"))(""))
    ((("v" ";"))(""))
    ((("z" ";"))(""))
    ((("/" ";"))(""))
    ((("1" "q"))(""))
    ((("2" "q"))(""))
    ((("3" "q"))(""))
    ((("4" "q"))(""))
    ((("5" "q"))(""))
    ((("6" "q"))(""))
    ((("7" "q"))(""))
    ((("8" "q"))("ú"))
    ((("9" "q"))(""))
    ((("0" "q"))(""))
    ((("," "q"))("Ū"))
    ((("." "q"))(""))
    ((("p" "q"))(""))
    ((("y" "q"))(""))
    ((("f" "q"))(""))
    ((("g" "q"))(""))
    ((("c" "q"))(""))
    ((("r" "q"))(""))
    ((("l" "q"))(""))
    ((("a" "q"))(""))
    ((("o" "q"))(""))
    ((("e" "q"))(""))
    ((("u" "q"))(""))
    ((("i" "q"))("̳"))
    ((("d" "q"))(""))
    ((("h" "q"))(""))
    ((("t" "q"))(""))
    ((("n" "q"))(""))
    ((("s" "q"))(""))
    (((";" "q"))(""))
    ((("q" "q"))(""))
    ((("j" "q"))(""))
    ((("k" "q"))("" ""))
    ((("x" "q"))(""))
    ((("b" "q"))(""))
    ((("m" "q"))(""))
    ((("w" "q"))(""))
    ((("v" "q"))(""))
    ((("z" "q"))(""))
    ((("/" "q"))(""))
    ((("1" "j"))(""))
    ((("2" "j"))(""))
    ((("3" "j"))(""))
    ((("4" "j"))(""))
    ((("5" "j"))(""))
    ;((("6" "j"))(""))
    ((("7" "j"))(""))
    ((("8" "j"))(""))
    ((("9" "j"))("ź"))
    ((("0" "j"))(""))
    ((("," "j"))(""))
    ((("." "j"))(""))
    ((("p" "j"))(""))
    ((("y" "j"))(""))
    ((("f" "j"))(""))
    ((("g" "j"))("ή"))
    ((("c" "j"))(""))
    ((("r" "j"))(""))
    ((("l" "j"))(""))
    ((("a" "j"))("͢"))
    ((("o" "j"))(""))
    ((("e" "j"))(""))
    ((("u" "j"))(""))
    ((("i" "j"))(""))
    ((("d" "j"))(""))
    ((("h" "j"))("Ϣ"))
    ((("t" "j"))(""))
    ((("n" "j"))(""))
    ((("s" "j"))(""))
    (((";" "j"))(""))
    ((("q" "j"))(""))
    ((("j" "j"))("Ŵ"))
    ((("k" "j"))(""))
    ((("x" "j"))(""))
    ((("b" "j"))(""))
    ((("m" "j"))(""))
    ((("w" "j"))("ĥ"))
    ((("v" "j"))(""))
    ((("z" "j"))(""))
    ((("/" "j"))(""))
    ((("1" "k"))(""))
    ((("2" "k"))(""))
    ((("3" "k"))(""))
    ((("4" "k"))(""))
    ((("5" "k"))(""))
    ;((("6" "k"))(""))
    ((("7" "k"))(""))
    ((("8" "k"))(""))
    ((("9" "k"))("Ű"))
    ((("0" "k"))("̦"))
    ((("," "k"))(""))
    ((("." "k"))(""))
    ((("p" "k"))(""))
    ((("y" "k"))(""))
    ((("f" "k"))(""))
    ((("g" "k"))(""))
    ((("c" "k"))(""))
    ((("r" "k"))(""))
    ((("l" "k"))("¾"))
    ((("a" "k"))(""))
    ((("o" "k"))(""))
    ((("e" "k"))("" ""))
    ((("u" "k"))(""))
    ((("i" "k"))(""))
    ((("d" "k"))("̣"))
    ((("h" "k"))(""))
    ((("t" "k"))(""))
    ((("n" "k"))("¼"))
    ((("s" "k"))(""))
    (((";" "k"))(""))
    ((("q" "k"))(""))
    ((("j" "k"))(""))
    ((("k" "k"))(""))
    ((("x" "k"))(""))
    ((("b" "k"))("̿"))
    ((("m" "k"))(""))
    ((("w" "k"))(""))
    ((("v" "k"))(""))
    ((("z" "k"))(""))
    ((("/" "k"))("" ""))
    ((("1" "x"))("" ""))
    ;((("2" "x"))(""))
    ;((("3" "x"))(""))
    ;((("4" "x"))(""))
    ;((("5" "x"))(""))
    ((("6" "x"))(""))
    ((("7" "x"))(""))
    ((("8" "x"))(""))
    ((("9" "x"))(""))
    ((("0" "x"))("Ȩ"))
    ((("," "x"))(""))
    ((("." "x"))(""))
    ((("p" "x"))(""))
    ((("y" "x"))(""))
    ((("f" "x"))(""))
    ((("g" "x"))(""))
    ((("c" "x"))(""))
    ((("r" "x"))("ͻ"))
    ((("l" "x"))(""))
    ((("a" "x"))(""))
    ((("o" "x"))(""))
    ((("e" "x"))("ˬ"))
    ((("u" "x"))("" ""))
    ((("i" "x"))(""))
    ((("d" "x"))(""))
    ((("h" "x"))(""))
    ((("t" "x"))(""))
    ((("n" "x"))(""))
    ((("s" "x"))(""))
    (((";" "x"))("Ʊ"))
    ((("q" "x"))(""))
    ((("j" "x"))(""))
    ((("k" "x"))(""))
    ((("x" "x"))(""))
    ((("b" "x"))(""))
    ((("m" "x"))(""))
    ((("w" "x"))(""))
    ((("v" "x"))(""))
    ((("z" "x"))("Ƚ"))
    ((("/" "x"))(""))
    ((("1" "b"))("" ""))
    ;((("2" "b"))(""))
    ;((("3" "b"))(""))
    ;((("4" "b"))(""))
    ;((("5" "b"))(""))
    ((("6" "b"))(""))
    ((("7" "b"))(""))
    ((("8" "b"))(""))
    ((("9" "b"))(""))
    ((("0" "b"))(""))
    ((("," "b"))(""))
    ((("." "b"))(""))
    ((("p" "b"))(""))
    ((("y" "b"))(""))
    ((("f" "b"))("˾"))
    ((("g" "b"))(""))
    ((("c" "b"))(""))
    ((("r" "b"))(""))
    ((("l" "b"))(""))
    ((("a" "b"))(""))
    ((("o" "b"))(""))
    ((("e" "b"))("̤"))
    ((("u" "b"))(""))
    ((("i" "b"))(""))
    ((("d" "b"))(""))
    ((("h" "b"))(""))
    ((("t" "b"))(""))
    ((("n" "b"))(""))
    ((("s" "b"))("" ""))
    (((";" "b"))("" ""))
    ((("q" "b"))("²"))
    ((("j" "b"))(""))
    ((("k" "b"))(""))
    ((("x" "b"))(""))
    ((("b" "b"))(""))
    ((("m" "b"))(""))
    ((("w" "b"))(""))
    ((("v" "b"))("ʡ"))
    ((("z" "b"))(""))
    ((("/" "b"))(""))
    ((("1" "m"))(""))
    ((("2" "m"))(""))
    ((("3" "m"))(""))
    ((("4" "m"))("Ǿ"))
    ((("5" "m"))("Ϸ"))
    ;((("6" "m"))(""))
    ;((("7" "m"))(""))
    ;((("8" "m"))(""))
    ;((("9" "m"))(""))
    ;((("0" "m"))(""))
    ((("," "m"))(""))
    ((("." "m"))(""))
    ((("p" "m"))(""))
    ((("y" "m"))(""))
    ((("f" "m"))(""))
    ((("g" "m"))(""))
    ((("c" "m"))("" ""))
    ((("r" "m"))("ã"))
    ((("l" "m"))(""))
    ((("a" "m"))(""))
    ((("o" "m"))(""))
    ((("e" "m"))(""))
    ((("u" "m"))("˺"))
    ((("i" "m"))("Ƥ"))
    ((("d" "m"))(""))
    ((("h" "m"))(""))
    ((("t" "m"))(""))
    ((("n" "m"))(""))
    ((("s" "m"))(""))
    (((";" "m"))(""))
    ((("q" "m"))(""))
    ((("j" "m"))("¿"))
    ((("k" "m"))(""))
    ((("x" "m"))(""))
    ((("b" "m"))(""))
    ((("m" "m"))(""))
    ((("w" "m"))(""))
    ((("v" "m"))(""))
    ((("z" "m"))("Ƿ"))
    ((("/" "m"))(""))
    ((("1" "w"))(""))
    ((("2" "w"))(""))
    ((("3" "w"))(""))
    ((("4" "w"))(""))
    ((("5" "w"))("Ȳ"))
    ((("6" "w"))(""))
    ((("7" "w"))(""))
    ((("8" "w"))(""))
    ((("9" "w"))(""))
    ((("0" "w"))(""))
    ((("," "w"))("" ""))
    ((("." "w"))(""))
    ((("p" "w"))(""))
    ((("y" "w"))(""))
    ((("f" "w"))(""))
    ((("g" "w"))(""))
    ((("c" "w"))("΢"))
    ((("r" "w"))("ͳ"))
    ((("l" "w"))(""))
    ((("a" "w"))(""))
    ((("o" "w"))("ɴ"))
    ((("e" "w"))(""))
    ((("u" "w"))("" ""))
    ((("i" "w"))(""))
    ((("d" "w"))(""))
    ((("h" "w"))("ʬ"))
    ((("t" "w"))(""))
    ((("n" "w"))(""))
    ((("s" "w"))(""))
    (((";" "w"))(""))
    ((("q" "w"))(""))
    ((("j" "w"))("" ""))
    ((("k" "w"))(""))
    ((("x" "w"))(""))
    ((("b" "w"))(""))
    ((("m" "w"))(""))
    ((("w" "w"))(""))
    ((("v" "w"))(""))
    ((("z" "w"))(""))
    ((("/" "w"))(""))
    ((("1" "v"))("" ""))
    ;((("2" "v"))(""))
    ;((("3" "v"))(""))
    ;((("4" "v"))(""))
    ;((("5" "v"))(""))
    ((("6" "v"))(""))
    ((("7" "v"))(""))
    ((("8" "v"))("" ""))
    ((("9" "v"))(""))
    ((("0" "v"))("Υ"))
    ((("," "v"))(""))
    ((("." "v"))(""))
    ((("p" "v"))(""))
    ((("y" "v"))(""))
    ((("f" "v"))("ľ"))
    ((("g" "v"))(""))
    ((("c" "v"))(""))
    ((("r" "v"))(""))
    ((("l" "v"))(""))
    ((("a" "v"))(""))
    ((("o" "v"))(""))
    ((("e" "v"))(""))
    ((("u" "v"))(""))
    ((("i" "v"))(""))
    ((("d" "v"))(""))
    ((("h" "v"))(""))
    ((("t" "v"))(""))
    ((("n" "v"))(""))
    ((("s" "v"))(""))
    (((";" "v"))(""))
    ((("q" "v"))(""))
    ((("j" "v"))(""))
    ((("k" "v"))("9"))
    ((("x" "v"))(""))
    ((("b" "v"))(""))
    ((("m" "v"))(""))
    ((("w" "v"))(""))
    ((("v" "v"))(""))
    ((("z" "v"))(""))
    ((("/" "v"))(""))
    ((("1" "z"))("" ""))
    ;((("2" "z"))(""))
    ((("3" "z"))(""))
    ;((("4" "z"))(""))
    ;((("5" "z"))(""))
    ((("6" "z"))(""))
    ((("7" "z"))(""))
    ((("8" "z"))(""))
    ((("9" "z"))(""))
    ((("0" "z"))(""))
    ((("," "z"))("" ""))
    ((("." "z"))(""))
    ((("p" "z"))("" ""))
    ((("y" "z"))("Ź"))
    ((("f" "z"))(""))
    ((("g" "z"))(""))
    ((("c" "z"))(""))
    ((("r" "z"))(""))
    ((("l" "z"))(""))
    ((("a" "z"))(""))
    ((("o" "z"))(""))
    ((("e" "z"))(""))
    ((("u" "z"))(""))
    ((("i" "z"))("Į"))
    ((("d" "z"))("´"))
    ((("h" "z"))(""))
    ((("t" "z"))(""))
    ((("n" "z"))(""))
    ((("s" "z"))("ͧ"))
    (((";" "z"))(""))
    ((("q" "z"))(""))
    ((("j" "z"))(""))
    ((("k" "z"))(""))
    ((("x" "z"))(""))
    ((("b" "z"))("%"))
    ((("m" "z"))("ƻ"))
    ((("w" "z"))(""))
    ((("v" "z"))(""))
    ((("z" "z"))(""))
    ((("/" "z"))("" ""))
    ((("1" "/"))(""))
    ((("2" "/"))(""))
    ((("3" "/"))(""))
    ((("4" "/"))("Ȣ"))
    ((("5" "/"))(""))
    ;((("6" "/"))(""))
    ;((("7" "/"))(""))
    ;((("8" "/"))(""))
    ;((("9" "/"))(""))
    ;((("0" "/"))(""))
    ((("," "/"))(""))
    ((("." "/"))("ȿ"))
    ((("p" "/"))(""))
    ((("y" "/"))("ô"))
    ((("f" "/"))(""))
    ((("g" "/"))("Ʋ"))
    ((("c" "/"))(""))
    ((("r" "/"))(""))
    ((("l" "/"))(""))
    ((("a" "/"))(""))
    ((("o" "/"))(""))
    ((("e" "/"))(""))
    ((("u" "/"))("Φ"))
    ((("i" "/"))(""))
    ((("d" "/"))(""))
    ((("h" "/"))(""))
    ((("t" "/"))(""))
    ((("n" "/"))(""))
    ((("s" "/"))(""))
    (((";" "/"))(""))
    ((("q" "/"))(""))
    ((("j" "/"))(""))
    ((("k" "/"))(""))
    ((("x" "/"))(""))
    ((("b" "/"))("ñ"))
    ((("m" "/"))(""))
    ((("w" "/"))("ȴ"))
    ((("v" "/"))(""))
    ((("z" "/"))(""))
    ((("/" "/"))(""))))

(define tcode-init-handler
  (lambda (id im arg)
    (generic-context-new id im tcode-rule #f)))

(generic-register-im
 'tcode
 "ja"
 "EUC-JP"
 (N_ "T-Code")
 (N_ "A kanji direct input method")
 tcode-init-handler)
